==> kubernetes-model-gatewayapi-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPPathModifierFluentImpl.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPPathModifierFluentImpl<A extends HTTPPathModifierFluent<A>> extends BaseFluent<A> implements HTTPPathModifierFluent<A>{
  public HTTPPathModifierFluentImpl() {
  }
  public HTTPPathModifierFluentImpl(HTTPPathModifier instance) {
    this.withReplaceFullPath(instance.getReplaceFullPath()); 
    this.withReplacePrefixMatch(instance.getReplacePrefixMatch()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String replaceFullPath;
  private String replacePrefixMatch;
  private String type;
  private Map<String,Object> additionalProperties;
  public String getReplaceFullPath() {
    return this.replaceFullPath;
  }
  public A withReplaceFullPath(String replaceFullPath) {
    this.replaceFullPath=replaceFullPath; return (A) this;
  }
  public Boolean hasReplaceFullPath() {
    return this.replaceFullPath != null;
  }
  public String getReplacePrefixMatch() {
    return this.replacePrefixMatch;
  }
  public A withReplacePrefixMatch(String replacePrefixMatch) {
    this.replacePrefixMatch=replacePrefixMatch; return (A) this;
  }
  public Boolean hasReplacePrefixMatch() {
    return this.replacePrefixMatch != null;
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTTPPathModifierFluentImpl that = (HTTPPathModifierFluentImpl) o;
    if (replaceFullPath != null ? !replaceFullPath.equals(that.replaceFullPath) :that.replaceFullPath != null) return false;
    if (replacePrefixMatch != null ? !replacePrefixMatch.equals(that.replacePrefixMatch) :that.replacePrefixMatch != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(replaceFullPath,  replacePrefixMatch,  type,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (replaceFullPath != null) { sb.append("replaceFullPath:"); sb.append(replaceFullPath + ","); }
    if (replacePrefixMatch != null) { sb.append("replacePrefixMatch:"); sb.append(replacePrefixMatch + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> kubernetes-model-gatewayapi-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPPathModifierFluentImpl.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPPathModifierFluentImpl<A extends HTTPPathModifierFluent<A>> extends BaseFluent<A> implements HTTPPathModifierFluent<A>{
  public HTTPPathModifierFluentImpl() {
  }
  public HTTPPathModifierFluentImpl(HTTPPathModifier instance) {
    if (instance != null) {
      this.withReplaceFullPath(instance.getReplaceFullPath());
      this.withReplacePrefixMatch(instance.getReplacePrefixMatch());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String replaceFullPath;
  private String replacePrefixMatch;
  private String type;
  private Map<String,Object> additionalProperties;
  public String getReplaceFullPath() {
    return this.replaceFullPath;
  }
  public A withReplaceFullPath(String replaceFullPath) {
    this.replaceFullPath=replaceFullPath; return (A) this;
  }
  public Boolean hasReplaceFullPath() {
    return this.replaceFullPath != null;
  }
  public String getReplacePrefixMatch() {
    return this.replacePrefixMatch;
  }
  public A withReplacePrefixMatch(String replacePrefixMatch) {
    this.replacePrefixMatch=replacePrefixMatch; return (A) this;
  }
  public Boolean hasReplacePrefixMatch() {
    return this.replacePrefixMatch != null;
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPPathModifierFluentImpl that = (HTTPPathModifierFluentImpl) o;
    if (!java.util.Objects.equals(replaceFullPath, that.replaceFullPath)) return false;

    if (!java.util.Objects.equals(replacePrefixMatch, that.replacePrefixMatch)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(replaceFullPath,  replacePrefixMatch,  type,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (replaceFullPath != null) { sb.append("replaceFullPath:"); sb.append(replaceFullPath + ","); }
    if (replacePrefixMatch != null) { sb.append("replacePrefixMatch:"); sb.append(replacePrefixMatch + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
